# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/desired_state/manager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from prodvana.proto.prodvana.desired_state.model import desired_state_pb2 as prodvana_dot_desired__state_dot_model_dot_desired__state__pb2
from prodvana.proto.prodvana.desired_state.model import entity_pb2 as prodvana_dot_desired__state_dot_model_dot_entity__pb2
from prodvana.proto.prodvana.service import service_config_pb2 as prodvana_dot_service_dot_service__config__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$prodvana/desired_state/manager.proto\x12\x16prodvana.desired_state\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x30prodvana/desired_state/model/desired_state.proto\x1a)prodvana/desired_state/model/entity.proto\x1a%prodvana/service/service_config.proto\x1a\x17validate/validate.proto\"l\n\x12SetDesiredStateReq\x12\x44\n\rdesired_state\x18\x01 \x01(\x0b\x32#.prodvana.desired_state.model.StateB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x10\n\x08rollback\x18\x02 \x01(\x08\"\xc4\x01\n\x17ValidateDesiredStateReq\x12\x44\n\rdesired_state\x18\x01 \x01(\x0b\x32#.prodvana.desired_state.model.StateB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x10\n\x08rollback\x18\x02 \x01(\x08\x12Q\n\x18service_instance_configs\x18\x03 \x03(\x0b\x32/.prodvana.service.CompiledServiceInstanceConfig\"/\n\x13SetDesiredStateResp\x12\x18\n\x10\x64\x65sired_state_id\x18\x01 \x01(\t\"e\n+GetServiceDesiredStateConvergenceSummaryReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"b\n\x12StatusExplanations\x12L\n\x13status_explanations\x18\x01 \x03(\x0b\x32/.prodvana.desired_state.model.StatusExplanation\"G\n\tDebugLogs\x12:\n\ndebug_logs\x18\x01 \x03(\x0b\x32&.prodvana.desired_state.model.DebugLog\"\xaf\x0f\n\x13\x44\x65siredStateSummary\x12?\n\x0c\x65ntity_graph\x18\x0f \x01(\x0b\x32).prodvana.desired_state.model.EntityGraph\x12;\n\x0estarting_state\x18\x01 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12<\n\x0flast_seen_state\x18\x02 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12:\n\rdesired_state\x18\x03 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12K\n\x08statuses\x18\x04 \x03(\x0b\x32\x39.prodvana.desired_state.DesiredStateSummary.StatusesEntry\x12\x36\n\x12\x63reation_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x36\n\x12replaced_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x64\n\x15precondition_statuses\x18\x08 \x03(\x0b\x32\x45.prodvana.desired_state.DesiredStateSummary.PreconditionStatusesEntry\x12`\n\x13status_explanations\x18\t \x03(\x0b\x32\x43.prodvana.desired_state.DesiredStateSummary.StatusExplanationsEntry\x12N\n\ndebug_logs\x18\n \x03(\x0b\x32:.prodvana.desired_state.DesiredStateSummary.DebugLogsEntry\x12`\n\x13\x61\x63tion_explanations\x18\x0b \x03(\x0b\x32\x43.prodvana.desired_state.DesiredStateSummary.ActionExplanationsEntry\x12\x65\n\x16last_update_timestamps\x18\x0c \x03(\x0b\x32\x45.prodvana.desired_state.DesiredStateSummary.LastUpdateTimestampsEntry\x12g\n\x17last_fetched_timestamps\x18\r \x03(\x0b\x32\x46.prodvana.desired_state.DesiredStateSummary.LastFetchedTimestampsEntry\x12g\n\x17last_applied_timestamps\x18\x0e \x03(\x0b\x32\x46.prodvana.desired_state.DesiredStateSummary.LastAppliedTimestampsEntry\x1aU\n\rStatusesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x33\n\x05value\x18\x02 \x01(\x0e\x32$.prodvana.desired_state.model.Status:\x02\x38\x01\x1ai\n\x19PreconditionStatusesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.prodvana.desired_state.model.ConditionState:\x02\x38\x01\x1a\x65\n\x17StatusExplanationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32*.prodvana.desired_state.StatusExplanations:\x02\x38\x01\x1aS\n\x0e\x44\x65\x62ugLogsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32!.prodvana.desired_state.DebugLogs:\x02\x38\x01\x1aj\n\x17\x41\x63tionExplanationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12>\n\x05value\x18\x02 \x01(\x0b\x32/.prodvana.desired_state.model.ActionExplanation:\x02\x38\x01\x1aW\n\x19LastUpdateTimestampsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x38\x01\x1aX\n\x1aLastFetchedTimestampsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x38\x01\x1aX\n\x1aLastAppliedTimestampsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp:\x02\x38\x01\"B\n\x1dGetDesiredStateConvergenceReq\x12!\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"e\n%GetDesiredStateConvergenceSummaryResp\x12<\n\x07summary\x18\x01 \x01(\x0b\x32+.prodvana.desired_state.DesiredStateSummary\"l\n,GetServiceDesiredStateConvergenceSummaryResp\x12<\n\x07summary\x18\x01 \x01(\x0b\x32+.prodvana.desired_state.DesiredStateSummary\"Y\n\x1fGetServiceLastConvergedStateReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"w\n GetServiceLastConvergedStateResp\x12S\n\x17service_instance_states\x18\x01 \x03(\x0b\x32\x32.prodvana.desired_state.model.ServiceInstanceState\"\x81\x01\n GetServiceDesiredStateHistoryReq\x12\x1c\n\x0b\x61pplication\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07service\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\"\x81\x01\n!GetServiceDesiredStateHistoryResp\x12\x43\n\x0e\x64\x65sired_states\x18\x01 \x03(\x0b\x32+.prodvana.desired_state.DesiredStateSummary\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"7\n\x12GetDesiredStateReq\x12!\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x96\x01\n\x13GetDesiredStateResp\x12:\n\rdesired_state\x18\x01 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x43\n\x16\x63ompiled_desired_state\x18\x02 \x01(\x0b\x32#.prodvana.desired_state.model.State\"\x9b\x01\n\x18ValidateDesiredStateResp\x12:\n\rdesired_state\x18\x01 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x43\n\x16\x63ompiled_desired_state\x18\x02 \x01(\x0b\x32#.prodvana.desired_state.model.State\"a\n\x14SetManualApprovalReq\x12!\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x16\n\x05topic\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x0e\n\x06reject\x18\x03 \x01(\x08\"\x17\n\x15SetManualApprovalResp\"m\n\x12PromoteDeliveryReq\x12!\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\r\n\x05stage\x18\x02 \x01(\x03\x12\x0c\n\x04\x66ull\x18\x03 \x01(\x08\x12\x17\n\x06source\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x15\n\x13PromoteDeliveryResp\"Q\n\x13\x42ypassProtectionReq\x12!\n\x10\x64\x65sired_state_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x17\n\x06source\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"\x16\n\x14\x42ypassProtectionResp2\xf5\x0e\n\x13\x44\x65siredStateManager\x12\x89\x01\n\x0fSetDesiredState\x12*.prodvana.desired_state.SetDesiredStateReq\x1a+.prodvana.desired_state.SetDesiredStateResp\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/desired_states:\x01*\x12\x89\x02\n(GetServiceDesiredStateConvergenceSummary\x12\x43.prodvana.desired_state.GetServiceDesiredStateConvergenceSummaryReq\x1a\x44.prodvana.desired_state.GetServiceDesiredStateConvergenceSummaryResp\"R\x82\xd3\xe4\x93\x02L\x12J/v1/applications/{application=*}/services/{service=*}/latest_desired_state\x12\xe0\x01\n\x1dGetServiceLastConvergedStates\x12\x37.prodvana.desired_state.GetServiceLastConvergedStateReq\x1a\x38.prodvana.desired_state.GetServiceLastConvergedStateResp\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/v1/applications/{application=*}/services/{service=*}/last_converged\x12\xe2\x01\n\x1dGetServiceDesiredStateHistory\x12\x38.prodvana.desired_state.GetServiceDesiredStateHistoryReq\x1a\x39.prodvana.desired_state.GetServiceDesiredStateHistoryResp\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/v1/applications/{application=*}/services/{service=*}/desired_states\x12\x9b\x01\n\x0fGetDesiredState\x12*.prodvana.desired_state.GetDesiredStateReq\x1a+.prodvana.desired_state.GetDesiredStateResp\"/\x82\xd3\xe4\x93\x02)\x12\'/v1/desired_states/{desired_state_id=*}\x12\xd2\x01\n!GetDesiredStateConvergenceSummary\x12\x35.prodvana.desired_state.GetDesiredStateConvergenceReq\x1a=.prodvana.desired_state.GetDesiredStateConvergenceSummaryResp\"7\x82\xd3\xe4\x93\x02\x31\x12//v1/desired_states/{desired_state_id=*}/summary\x12\xa1\x01\n\x14ValidateDesiredState\x12/.prodvana.desired_state.ValidateDesiredStateReq\x1a\x30.prodvana.desired_state.ValidateDesiredStateResp\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/desired_states/validate:\x01*\x12\xa8\x01\n\x11SetManualApproval\x12,.prodvana.desired_state.SetManualApprovalReq\x1a-.prodvana.desired_state.SetManualApprovalResp\"6\x82\xd3\xe4\x93\x02\x30\"+/v1/desired_states/approve_manual_condition:\x01*\x12\x9a\x01\n\x0fPromoteDelivery\x12*.prodvana.desired_state.PromoteDeliveryReq\x1a+.prodvana.desired_state.PromoteDeliveryResp\".\x82\xd3\xe4\x93\x02(\"#/v1/desired_states/promote_delivery:\x01*\x12\x9e\x01\n\x10\x42ypassProtection\x12+.prodvana.desired_state.BypassProtectionReq\x1a,.prodvana.desired_state.BypassProtectionResp\"/\x82\xd3\xe4\x93\x02)\"$/v1/desired_states/bypass_protection:\x01*BRZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_stateb\x06proto3')



_SETDESIREDSTATEREQ = DESCRIPTOR.message_types_by_name['SetDesiredStateReq']
_VALIDATEDESIREDSTATEREQ = DESCRIPTOR.message_types_by_name['ValidateDesiredStateReq']
_SETDESIREDSTATERESP = DESCRIPTOR.message_types_by_name['SetDesiredStateResp']
_GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ = DESCRIPTOR.message_types_by_name['GetServiceDesiredStateConvergenceSummaryReq']
_STATUSEXPLANATIONS = DESCRIPTOR.message_types_by_name['StatusExplanations']
_DEBUGLOGS = DESCRIPTOR.message_types_by_name['DebugLogs']
_DESIREDSTATESUMMARY = DESCRIPTOR.message_types_by_name['DesiredStateSummary']
_DESIREDSTATESUMMARY_STATUSESENTRY = _DESIREDSTATESUMMARY.nested_types_by_name['StatusesEntry']
_DESIREDSTATESUMMARY_PRECONDITIONSTATUSESENTRY = _DESIREDSTATESUMMARY.nested_types_by_name['PreconditionStatusesEntry']
_DESIREDSTATESUMMARY_STATUSEXPLANATIONSENTRY = _DESIREDSTATESUMMARY.nested_types_by_name['StatusExplanationsEntry']
_DESIREDSTATESUMMARY_DEBUGLOGSENTRY = _DESIREDSTATESUMMARY.nested_types_by_name['DebugLogsEntry']
_DESIREDSTATESUMMARY_ACTIONEXPLANATIONSENTRY = _DESIREDSTATESUMMARY.nested_types_by_name['ActionExplanationsEntry']
_DESIREDSTATESUMMARY_LASTUPDATETIMESTAMPSENTRY = _DESIREDSTATESUMMARY.nested_types_by_name['LastUpdateTimestampsEntry']
_DESIREDSTATESUMMARY_LASTFETCHEDTIMESTAMPSENTRY = _DESIREDSTATESUMMARY.nested_types_by_name['LastFetchedTimestampsEntry']
_DESIREDSTATESUMMARY_LASTAPPLIEDTIMESTAMPSENTRY = _DESIREDSTATESUMMARY.nested_types_by_name['LastAppliedTimestampsEntry']
_GETDESIREDSTATECONVERGENCEREQ = DESCRIPTOR.message_types_by_name['GetDesiredStateConvergenceReq']
_GETDESIREDSTATECONVERGENCESUMMARYRESP = DESCRIPTOR.message_types_by_name['GetDesiredStateConvergenceSummaryResp']
_GETSERVICEDESIREDSTATECONVERGENCESUMMARYRESP = DESCRIPTOR.message_types_by_name['GetServiceDesiredStateConvergenceSummaryResp']
_GETSERVICELASTCONVERGEDSTATEREQ = DESCRIPTOR.message_types_by_name['GetServiceLastConvergedStateReq']
_GETSERVICELASTCONVERGEDSTATERESP = DESCRIPTOR.message_types_by_name['GetServiceLastConvergedStateResp']
_GETSERVICEDESIREDSTATEHISTORYREQ = DESCRIPTOR.message_types_by_name['GetServiceDesiredStateHistoryReq']
_GETSERVICEDESIREDSTATEHISTORYRESP = DESCRIPTOR.message_types_by_name['GetServiceDesiredStateHistoryResp']
_GETDESIREDSTATEREQ = DESCRIPTOR.message_types_by_name['GetDesiredStateReq']
_GETDESIREDSTATERESP = DESCRIPTOR.message_types_by_name['GetDesiredStateResp']
_VALIDATEDESIREDSTATERESP = DESCRIPTOR.message_types_by_name['ValidateDesiredStateResp']
_SETMANUALAPPROVALREQ = DESCRIPTOR.message_types_by_name['SetManualApprovalReq']
_SETMANUALAPPROVALRESP = DESCRIPTOR.message_types_by_name['SetManualApprovalResp']
_PROMOTEDELIVERYREQ = DESCRIPTOR.message_types_by_name['PromoteDeliveryReq']
_PROMOTEDELIVERYRESP = DESCRIPTOR.message_types_by_name['PromoteDeliveryResp']
_BYPASSPROTECTIONREQ = DESCRIPTOR.message_types_by_name['BypassProtectionReq']
_BYPASSPROTECTIONRESP = DESCRIPTOR.message_types_by_name['BypassProtectionResp']
SetDesiredStateReq = _reflection.GeneratedProtocolMessageType('SetDesiredStateReq', (_message.Message,), {
  'DESCRIPTOR' : _SETDESIREDSTATEREQ,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.SetDesiredStateReq)
  })
_sym_db.RegisterMessage(SetDesiredStateReq)

ValidateDesiredStateReq = _reflection.GeneratedProtocolMessageType('ValidateDesiredStateReq', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEDESIREDSTATEREQ,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.ValidateDesiredStateReq)
  })
_sym_db.RegisterMessage(ValidateDesiredStateReq)

SetDesiredStateResp = _reflection.GeneratedProtocolMessageType('SetDesiredStateResp', (_message.Message,), {
  'DESCRIPTOR' : _SETDESIREDSTATERESP,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.SetDesiredStateResp)
  })
_sym_db.RegisterMessage(SetDesiredStateResp)

GetServiceDesiredStateConvergenceSummaryReq = _reflection.GeneratedProtocolMessageType('GetServiceDesiredStateConvergenceSummaryReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.GetServiceDesiredStateConvergenceSummaryReq)
  })
_sym_db.RegisterMessage(GetServiceDesiredStateConvergenceSummaryReq)

StatusExplanations = _reflection.GeneratedProtocolMessageType('StatusExplanations', (_message.Message,), {
  'DESCRIPTOR' : _STATUSEXPLANATIONS,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.StatusExplanations)
  })
_sym_db.RegisterMessage(StatusExplanations)

DebugLogs = _reflection.GeneratedProtocolMessageType('DebugLogs', (_message.Message,), {
  'DESCRIPTOR' : _DEBUGLOGS,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.DebugLogs)
  })
_sym_db.RegisterMessage(DebugLogs)

DesiredStateSummary = _reflection.GeneratedProtocolMessageType('DesiredStateSummary', (_message.Message,), {

  'StatusesEntry' : _reflection.GeneratedProtocolMessageType('StatusesEntry', (_message.Message,), {
    'DESCRIPTOR' : _DESIREDSTATESUMMARY_STATUSESENTRY,
    '__module__' : 'prodvana.desired_state.manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.desired_state.DesiredStateSummary.StatusesEntry)
    })
  ,

  'PreconditionStatusesEntry' : _reflection.GeneratedProtocolMessageType('PreconditionStatusesEntry', (_message.Message,), {
    'DESCRIPTOR' : _DESIREDSTATESUMMARY_PRECONDITIONSTATUSESENTRY,
    '__module__' : 'prodvana.desired_state.manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.desired_state.DesiredStateSummary.PreconditionStatusesEntry)
    })
  ,

  'StatusExplanationsEntry' : _reflection.GeneratedProtocolMessageType('StatusExplanationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DESIREDSTATESUMMARY_STATUSEXPLANATIONSENTRY,
    '__module__' : 'prodvana.desired_state.manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.desired_state.DesiredStateSummary.StatusExplanationsEntry)
    })
  ,

  'DebugLogsEntry' : _reflection.GeneratedProtocolMessageType('DebugLogsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DESIREDSTATESUMMARY_DEBUGLOGSENTRY,
    '__module__' : 'prodvana.desired_state.manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.desired_state.DesiredStateSummary.DebugLogsEntry)
    })
  ,

  'ActionExplanationsEntry' : _reflection.GeneratedProtocolMessageType('ActionExplanationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DESIREDSTATESUMMARY_ACTIONEXPLANATIONSENTRY,
    '__module__' : 'prodvana.desired_state.manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.desired_state.DesiredStateSummary.ActionExplanationsEntry)
    })
  ,

  'LastUpdateTimestampsEntry' : _reflection.GeneratedProtocolMessageType('LastUpdateTimestampsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DESIREDSTATESUMMARY_LASTUPDATETIMESTAMPSENTRY,
    '__module__' : 'prodvana.desired_state.manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.desired_state.DesiredStateSummary.LastUpdateTimestampsEntry)
    })
  ,

  'LastFetchedTimestampsEntry' : _reflection.GeneratedProtocolMessageType('LastFetchedTimestampsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DESIREDSTATESUMMARY_LASTFETCHEDTIMESTAMPSENTRY,
    '__module__' : 'prodvana.desired_state.manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.desired_state.DesiredStateSummary.LastFetchedTimestampsEntry)
    })
  ,

  'LastAppliedTimestampsEntry' : _reflection.GeneratedProtocolMessageType('LastAppliedTimestampsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DESIREDSTATESUMMARY_LASTAPPLIEDTIMESTAMPSENTRY,
    '__module__' : 'prodvana.desired_state.manager_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.desired_state.DesiredStateSummary.LastAppliedTimestampsEntry)
    })
  ,
  'DESCRIPTOR' : _DESIREDSTATESUMMARY,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.DesiredStateSummary)
  })
_sym_db.RegisterMessage(DesiredStateSummary)
_sym_db.RegisterMessage(DesiredStateSummary.StatusesEntry)
_sym_db.RegisterMessage(DesiredStateSummary.PreconditionStatusesEntry)
_sym_db.RegisterMessage(DesiredStateSummary.StatusExplanationsEntry)
_sym_db.RegisterMessage(DesiredStateSummary.DebugLogsEntry)
_sym_db.RegisterMessage(DesiredStateSummary.ActionExplanationsEntry)
_sym_db.RegisterMessage(DesiredStateSummary.LastUpdateTimestampsEntry)
_sym_db.RegisterMessage(DesiredStateSummary.LastFetchedTimestampsEntry)
_sym_db.RegisterMessage(DesiredStateSummary.LastAppliedTimestampsEntry)

GetDesiredStateConvergenceReq = _reflection.GeneratedProtocolMessageType('GetDesiredStateConvergenceReq', (_message.Message,), {
  'DESCRIPTOR' : _GETDESIREDSTATECONVERGENCEREQ,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.GetDesiredStateConvergenceReq)
  })
_sym_db.RegisterMessage(GetDesiredStateConvergenceReq)

GetDesiredStateConvergenceSummaryResp = _reflection.GeneratedProtocolMessageType('GetDesiredStateConvergenceSummaryResp', (_message.Message,), {
  'DESCRIPTOR' : _GETDESIREDSTATECONVERGENCESUMMARYRESP,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.GetDesiredStateConvergenceSummaryResp)
  })
_sym_db.RegisterMessage(GetDesiredStateConvergenceSummaryResp)

GetServiceDesiredStateConvergenceSummaryResp = _reflection.GeneratedProtocolMessageType('GetServiceDesiredStateConvergenceSummaryResp', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEDESIREDSTATECONVERGENCESUMMARYRESP,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.GetServiceDesiredStateConvergenceSummaryResp)
  })
_sym_db.RegisterMessage(GetServiceDesiredStateConvergenceSummaryResp)

GetServiceLastConvergedStateReq = _reflection.GeneratedProtocolMessageType('GetServiceLastConvergedStateReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICELASTCONVERGEDSTATEREQ,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.GetServiceLastConvergedStateReq)
  })
_sym_db.RegisterMessage(GetServiceLastConvergedStateReq)

GetServiceLastConvergedStateResp = _reflection.GeneratedProtocolMessageType('GetServiceLastConvergedStateResp', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICELASTCONVERGEDSTATERESP,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.GetServiceLastConvergedStateResp)
  })
_sym_db.RegisterMessage(GetServiceLastConvergedStateResp)

GetServiceDesiredStateHistoryReq = _reflection.GeneratedProtocolMessageType('GetServiceDesiredStateHistoryReq', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEDESIREDSTATEHISTORYREQ,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.GetServiceDesiredStateHistoryReq)
  })
_sym_db.RegisterMessage(GetServiceDesiredStateHistoryReq)

GetServiceDesiredStateHistoryResp = _reflection.GeneratedProtocolMessageType('GetServiceDesiredStateHistoryResp', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEDESIREDSTATEHISTORYRESP,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.GetServiceDesiredStateHistoryResp)
  })
_sym_db.RegisterMessage(GetServiceDesiredStateHistoryResp)

GetDesiredStateReq = _reflection.GeneratedProtocolMessageType('GetDesiredStateReq', (_message.Message,), {
  'DESCRIPTOR' : _GETDESIREDSTATEREQ,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.GetDesiredStateReq)
  })
_sym_db.RegisterMessage(GetDesiredStateReq)

GetDesiredStateResp = _reflection.GeneratedProtocolMessageType('GetDesiredStateResp', (_message.Message,), {
  'DESCRIPTOR' : _GETDESIREDSTATERESP,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.GetDesiredStateResp)
  })
_sym_db.RegisterMessage(GetDesiredStateResp)

ValidateDesiredStateResp = _reflection.GeneratedProtocolMessageType('ValidateDesiredStateResp', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATEDESIREDSTATERESP,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.ValidateDesiredStateResp)
  })
_sym_db.RegisterMessage(ValidateDesiredStateResp)

SetManualApprovalReq = _reflection.GeneratedProtocolMessageType('SetManualApprovalReq', (_message.Message,), {
  'DESCRIPTOR' : _SETMANUALAPPROVALREQ,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.SetManualApprovalReq)
  })
_sym_db.RegisterMessage(SetManualApprovalReq)

SetManualApprovalResp = _reflection.GeneratedProtocolMessageType('SetManualApprovalResp', (_message.Message,), {
  'DESCRIPTOR' : _SETMANUALAPPROVALRESP,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.SetManualApprovalResp)
  })
_sym_db.RegisterMessage(SetManualApprovalResp)

PromoteDeliveryReq = _reflection.GeneratedProtocolMessageType('PromoteDeliveryReq', (_message.Message,), {
  'DESCRIPTOR' : _PROMOTEDELIVERYREQ,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.PromoteDeliveryReq)
  })
_sym_db.RegisterMessage(PromoteDeliveryReq)

PromoteDeliveryResp = _reflection.GeneratedProtocolMessageType('PromoteDeliveryResp', (_message.Message,), {
  'DESCRIPTOR' : _PROMOTEDELIVERYRESP,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.PromoteDeliveryResp)
  })
_sym_db.RegisterMessage(PromoteDeliveryResp)

BypassProtectionReq = _reflection.GeneratedProtocolMessageType('BypassProtectionReq', (_message.Message,), {
  'DESCRIPTOR' : _BYPASSPROTECTIONREQ,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.BypassProtectionReq)
  })
_sym_db.RegisterMessage(BypassProtectionReq)

BypassProtectionResp = _reflection.GeneratedProtocolMessageType('BypassProtectionResp', (_message.Message,), {
  'DESCRIPTOR' : _BYPASSPROTECTIONRESP,
  '__module__' : 'prodvana.desired_state.manager_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.desired_state.BypassProtectionResp)
  })
_sym_db.RegisterMessage(BypassProtectionResp)

_DESIREDSTATEMANAGER = DESCRIPTOR.services_by_name['DesiredStateManager']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/desired_state'
  _SETDESIREDSTATEREQ.fields_by_name['desired_state']._options = None
  _SETDESIREDSTATEREQ.fields_by_name['desired_state']._serialized_options = b'\372B\005\212\001\002\020\001'
  _VALIDATEDESIREDSTATEREQ.fields_by_name['desired_state']._options = None
  _VALIDATEDESIREDSTATEREQ.fields_by_name['desired_state']._serialized_options = b'\372B\005\212\001\002\020\001'
  _GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ.fields_by_name['application']._options = None
  _GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ.fields_by_name['service']._options = None
  _GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _DESIREDSTATESUMMARY_STATUSESENTRY._options = None
  _DESIREDSTATESUMMARY_STATUSESENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_PRECONDITIONSTATUSESENTRY._options = None
  _DESIREDSTATESUMMARY_PRECONDITIONSTATUSESENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_STATUSEXPLANATIONSENTRY._options = None
  _DESIREDSTATESUMMARY_STATUSEXPLANATIONSENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_DEBUGLOGSENTRY._options = None
  _DESIREDSTATESUMMARY_DEBUGLOGSENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_ACTIONEXPLANATIONSENTRY._options = None
  _DESIREDSTATESUMMARY_ACTIONEXPLANATIONSENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_LASTUPDATETIMESTAMPSENTRY._options = None
  _DESIREDSTATESUMMARY_LASTUPDATETIMESTAMPSENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_LASTFETCHEDTIMESTAMPSENTRY._options = None
  _DESIREDSTATESUMMARY_LASTFETCHEDTIMESTAMPSENTRY._serialized_options = b'8\001'
  _DESIREDSTATESUMMARY_LASTAPPLIEDTIMESTAMPSENTRY._options = None
  _DESIREDSTATESUMMARY_LASTAPPLIEDTIMESTAMPSENTRY._serialized_options = b'8\001'
  _GETDESIREDSTATECONVERGENCEREQ.fields_by_name['desired_state_id']._options = None
  _GETDESIREDSTATECONVERGENCEREQ.fields_by_name['desired_state_id']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICELASTCONVERGEDSTATEREQ.fields_by_name['application']._options = None
  _GETSERVICELASTCONVERGEDSTATEREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICELASTCONVERGEDSTATEREQ.fields_by_name['service']._options = None
  _GETSERVICELASTCONVERGEDSTATEREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEDESIREDSTATEHISTORYREQ.fields_by_name['application']._options = None
  _GETSERVICEDESIREDSTATEHISTORYREQ.fields_by_name['application']._serialized_options = b'\372B\004r\002\020\001'
  _GETSERVICEDESIREDSTATEHISTORYREQ.fields_by_name['service']._options = None
  _GETSERVICEDESIREDSTATEHISTORYREQ.fields_by_name['service']._serialized_options = b'\372B\004r\002\020\001'
  _GETDESIREDSTATEREQ.fields_by_name['desired_state_id']._options = None
  _GETDESIREDSTATEREQ.fields_by_name['desired_state_id']._serialized_options = b'\372B\004r\002\020\001'
  _SETMANUALAPPROVALREQ.fields_by_name['desired_state_id']._options = None
  _SETMANUALAPPROVALREQ.fields_by_name['desired_state_id']._serialized_options = b'\372B\004r\002\020\001'
  _SETMANUALAPPROVALREQ.fields_by_name['topic']._options = None
  _SETMANUALAPPROVALREQ.fields_by_name['topic']._serialized_options = b'\372B\004r\002\020\001'
  _PROMOTEDELIVERYREQ.fields_by_name['desired_state_id']._options = None
  _PROMOTEDELIVERYREQ.fields_by_name['desired_state_id']._serialized_options = b'\372B\004r\002\020\001'
  _PROMOTEDELIVERYREQ.fields_by_name['source']._options = None
  _PROMOTEDELIVERYREQ.fields_by_name['source']._serialized_options = b'\372B\004r\002\020\001'
  _BYPASSPROTECTIONREQ.fields_by_name['desired_state_id']._options = None
  _BYPASSPROTECTIONREQ.fields_by_name['desired_state_id']._serialized_options = b'\372B\004r\002\020\001'
  _BYPASSPROTECTIONREQ.fields_by_name['source']._options = None
  _BYPASSPROTECTIONREQ.fields_by_name['source']._serialized_options = b'\372B\004r\002\020\001'
  _DESIREDSTATEMANAGER.methods_by_name['SetDesiredState']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['SetDesiredState']._serialized_options = b'\202\323\344\223\002\027\"\022/v1/desired_states:\001*'
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceDesiredStateConvergenceSummary']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceDesiredStateConvergenceSummary']._serialized_options = b'\202\323\344\223\002L\022J/v1/applications/{application=*}/services/{service=*}/latest_desired_state'
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceLastConvergedStates']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceLastConvergedStates']._serialized_options = b'\202\323\344\223\002F\022D/v1/applications/{application=*}/services/{service=*}/last_converged'
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceDesiredStateHistory']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetServiceDesiredStateHistory']._serialized_options = b'\202\323\344\223\002F\022D/v1/applications/{application=*}/services/{service=*}/desired_states'
  _DESIREDSTATEMANAGER.methods_by_name['GetDesiredState']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetDesiredState']._serialized_options = b'\202\323\344\223\002)\022\'/v1/desired_states/{desired_state_id=*}'
  _DESIREDSTATEMANAGER.methods_by_name['GetDesiredStateConvergenceSummary']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['GetDesiredStateConvergenceSummary']._serialized_options = b'\202\323\344\223\0021\022//v1/desired_states/{desired_state_id=*}/summary'
  _DESIREDSTATEMANAGER.methods_by_name['ValidateDesiredState']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['ValidateDesiredState']._serialized_options = b'\202\323\344\223\002 \"\033/v1/desired_states/validate:\001*'
  _DESIREDSTATEMANAGER.methods_by_name['SetManualApproval']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['SetManualApproval']._serialized_options = b'\202\323\344\223\0020\"+/v1/desired_states/approve_manual_condition:\001*'
  _DESIREDSTATEMANAGER.methods_by_name['PromoteDelivery']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['PromoteDelivery']._serialized_options = b'\202\323\344\223\002(\"#/v1/desired_states/promote_delivery:\001*'
  _DESIREDSTATEMANAGER.methods_by_name['BypassProtection']._options = None
  _DESIREDSTATEMANAGER.methods_by_name['BypassProtection']._serialized_options = b'\202\323\344\223\002)\"$/v1/desired_states/bypass_protection:\001*'
  _SETDESIREDSTATEREQ._serialized_start=284
  _SETDESIREDSTATEREQ._serialized_end=392
  _VALIDATEDESIREDSTATEREQ._serialized_start=395
  _VALIDATEDESIREDSTATEREQ._serialized_end=591
  _SETDESIREDSTATERESP._serialized_start=593
  _SETDESIREDSTATERESP._serialized_end=640
  _GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ._serialized_start=642
  _GETSERVICEDESIREDSTATECONVERGENCESUMMARYREQ._serialized_end=743
  _STATUSEXPLANATIONS._serialized_start=745
  _STATUSEXPLANATIONS._serialized_end=843
  _DEBUGLOGS._serialized_start=845
  _DEBUGLOGS._serialized_end=916
  _DESIREDSTATESUMMARY._serialized_start=919
  _DESIREDSTATESUMMARY._serialized_end=2886
  _DESIREDSTATESUMMARY_STATUSESENTRY._serialized_start=2129
  _DESIREDSTATESUMMARY_STATUSESENTRY._serialized_end=2214
  _DESIREDSTATESUMMARY_PRECONDITIONSTATUSESENTRY._serialized_start=2216
  _DESIREDSTATESUMMARY_PRECONDITIONSTATUSESENTRY._serialized_end=2321
  _DESIREDSTATESUMMARY_STATUSEXPLANATIONSENTRY._serialized_start=2323
  _DESIREDSTATESUMMARY_STATUSEXPLANATIONSENTRY._serialized_end=2424
  _DESIREDSTATESUMMARY_DEBUGLOGSENTRY._serialized_start=2426
  _DESIREDSTATESUMMARY_DEBUGLOGSENTRY._serialized_end=2509
  _DESIREDSTATESUMMARY_ACTIONEXPLANATIONSENTRY._serialized_start=2511
  _DESIREDSTATESUMMARY_ACTIONEXPLANATIONSENTRY._serialized_end=2617
  _DESIREDSTATESUMMARY_LASTUPDATETIMESTAMPSENTRY._serialized_start=2619
  _DESIREDSTATESUMMARY_LASTUPDATETIMESTAMPSENTRY._serialized_end=2706
  _DESIREDSTATESUMMARY_LASTFETCHEDTIMESTAMPSENTRY._serialized_start=2708
  _DESIREDSTATESUMMARY_LASTFETCHEDTIMESTAMPSENTRY._serialized_end=2796
  _DESIREDSTATESUMMARY_LASTAPPLIEDTIMESTAMPSENTRY._serialized_start=2798
  _DESIREDSTATESUMMARY_LASTAPPLIEDTIMESTAMPSENTRY._serialized_end=2886
  _GETDESIREDSTATECONVERGENCEREQ._serialized_start=2888
  _GETDESIREDSTATECONVERGENCEREQ._serialized_end=2954
  _GETDESIREDSTATECONVERGENCESUMMARYRESP._serialized_start=2956
  _GETDESIREDSTATECONVERGENCESUMMARYRESP._serialized_end=3057
  _GETSERVICEDESIREDSTATECONVERGENCESUMMARYRESP._serialized_start=3059
  _GETSERVICEDESIREDSTATECONVERGENCESUMMARYRESP._serialized_end=3167
  _GETSERVICELASTCONVERGEDSTATEREQ._serialized_start=3169
  _GETSERVICELASTCONVERGEDSTATEREQ._serialized_end=3258
  _GETSERVICELASTCONVERGEDSTATERESP._serialized_start=3260
  _GETSERVICELASTCONVERGEDSTATERESP._serialized_end=3379
  _GETSERVICEDESIREDSTATEHISTORYREQ._serialized_start=3382
  _GETSERVICEDESIREDSTATEHISTORYREQ._serialized_end=3511
  _GETSERVICEDESIREDSTATEHISTORYRESP._serialized_start=3514
  _GETSERVICEDESIREDSTATEHISTORYRESP._serialized_end=3643
  _GETDESIREDSTATEREQ._serialized_start=3645
  _GETDESIREDSTATEREQ._serialized_end=3700
  _GETDESIREDSTATERESP._serialized_start=3703
  _GETDESIREDSTATERESP._serialized_end=3853
  _VALIDATEDESIREDSTATERESP._serialized_start=3856
  _VALIDATEDESIREDSTATERESP._serialized_end=4011
  _SETMANUALAPPROVALREQ._serialized_start=4013
  _SETMANUALAPPROVALREQ._serialized_end=4110
  _SETMANUALAPPROVALRESP._serialized_start=4112
  _SETMANUALAPPROVALRESP._serialized_end=4135
  _PROMOTEDELIVERYREQ._serialized_start=4137
  _PROMOTEDELIVERYREQ._serialized_end=4246
  _PROMOTEDELIVERYRESP._serialized_start=4248
  _PROMOTEDELIVERYRESP._serialized_end=4269
  _BYPASSPROTECTIONREQ._serialized_start=4271
  _BYPASSPROTECTIONREQ._serialized_end=4352
  _BYPASSPROTECTIONRESP._serialized_start=4354
  _BYPASSPROTECTIONRESP._serialized_end=4376
  _DESIREDSTATEMANAGER._serialized_start=4379
  _DESIREDSTATEMANAGER._serialized_end=6288
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/service/object.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.object import meta_pb2 as prodvana_dot_object_dot_meta__pb2
from prodvana.proto.prodvana.common_config import meta_pb2 as prodvana_dot_common__config_dot_meta__pb2
from prodvana.proto.prodvana.service import service_config_pb2 as prodvana_dot_service_dot_service__config__pb2
from prodvana.proto.prodvana.service import user_metadata_pb2 as prodvana_dot_service_dot_user__metadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dprodvana/service/object.proto\x12\x10prodvana.service\x1a\x1aprodvana/object/meta.proto\x1a!prodvana/common_config/meta.proto\x1a%prodvana/service/service_config.proto\x1a$prodvana/service/user_metadata.proto\"\x9a\x01\n\x0c\x45xternalAddr\x12\x0c\n\x04\x61\x64\x64r\x18\x01 \x01(\t\x12\x31\n\x04type\x18\x02 \x01(\x0e\x32#.prodvana.service.ExternalAddr.Type\"I\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\x12\n\n\x06RAW_IP\x10\x03\x12\x10\n\x0cRAW_HOSTNAME\x10\x04\"8\n\x0cServiceStateJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03R\x15ongoing_pipeline_runsR\x05state\"\xd2\x01\n\x07Service\x12)\n\x04meta\x18\x01 \x01(\x0b\x32\x1b.prodvana.object.ObjectMeta\x12/\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1f.prodvana.service.ServiceConfig\x12-\n\x05state\x18\x03 \x01(\x0b\x32\x1e.prodvana.service.ServiceState\x12<\n\ruser_metadata\x18\x04 \x01(\x0b\x32%.prodvana.service.ServiceUserMetadata\"\xda\x02\n\x14ServiceInstanceState\x12\x36\n\x0e\x65xternal_addrs\x18\x07 \x03(\x0b\x32\x1e.prodvana.service.ExternalAddrJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x08\x10\tJ\x04\x08\t\x10\nJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0cJ\x04\x08\x0c\x10\rR\x05stateR\x0e\x61vailable_podsR\x0c\x64\x65sired_podsR\x1flatest_successful_prodvana_pushR2latest_successful_unknown_push_after_prodvana_pushR\x0congoing_pushR\x04podsR\nruntime_idR\x0cruntime_nameR\x10writeback_configR\x0e\x64\x65livery_state\"\xca\x01\n\x0fServiceInstance\x12?\n\x04meta\x18\x01 \x01(\x0b\x32\x31.prodvana.common_config.ServiceInstanceObjectMeta\x12?\n\x06\x63onfig\x18\x02 \x01(\x0b\x32/.prodvana.service.CompiledServiceInstanceConfig\x12\x35\n\x05state\x18\x03 \x01(\x0b\x32&.prodvana.service.ServiceInstanceStateBLZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/serviceb\x06proto3')



_EXTERNALADDR = DESCRIPTOR.message_types_by_name['ExternalAddr']
_SERVICESTATE = DESCRIPTOR.message_types_by_name['ServiceState']
_SERVICE = DESCRIPTOR.message_types_by_name['Service']
_SERVICEINSTANCESTATE = DESCRIPTOR.message_types_by_name['ServiceInstanceState']
_SERVICEINSTANCE = DESCRIPTOR.message_types_by_name['ServiceInstance']
_EXTERNALADDR_TYPE = _EXTERNALADDR.enum_types_by_name['Type']
ExternalAddr = _reflection.GeneratedProtocolMessageType('ExternalAddr', (_message.Message,), {
  'DESCRIPTOR' : _EXTERNALADDR,
  '__module__' : 'prodvana.service.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ExternalAddr)
  })
_sym_db.RegisterMessage(ExternalAddr)

ServiceState = _reflection.GeneratedProtocolMessageType('ServiceState', (_message.Message,), {
  'DESCRIPTOR' : _SERVICESTATE,
  '__module__' : 'prodvana.service.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ServiceState)
  })
_sym_db.RegisterMessage(ServiceState)

Service = _reflection.GeneratedProtocolMessageType('Service', (_message.Message,), {
  'DESCRIPTOR' : _SERVICE,
  '__module__' : 'prodvana.service.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.Service)
  })
_sym_db.RegisterMessage(Service)

ServiceInstanceState = _reflection.GeneratedProtocolMessageType('ServiceInstanceState', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEINSTANCESTATE,
  '__module__' : 'prodvana.service.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ServiceInstanceState)
  })
_sym_db.RegisterMessage(ServiceInstanceState)

ServiceInstance = _reflection.GeneratedProtocolMessageType('ServiceInstance', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEINSTANCE,
  '__module__' : 'prodvana.service.object_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.service.ServiceInstance)
  })
_sym_db.RegisterMessage(ServiceInstance)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZJgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/service'
  _EXTERNALADDR._serialized_start=192
  _EXTERNALADDR._serialized_end=346
  _EXTERNALADDR_TYPE._serialized_start=273
  _EXTERNALADDR_TYPE._serialized_end=346
  _SERVICESTATE._serialized_start=348
  _SERVICESTATE._serialized_end=404
  _SERVICE._serialized_start=407
  _SERVICE._serialized_end=617
  _SERVICEINSTANCESTATE._serialized_start=620
  _SERVICEINSTANCESTATE._serialized_end=966
  _SERVICEINSTANCE._serialized_start=969
  _SERVICEINSTANCE._serialized_end=1171
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/protection/attachments.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.protection import protection_reference_pb2 as prodvana_dot_protection_dot_protection__reference__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%prodvana/protection/attachments.proto\x12\x13prodvana.protection\x1a.prodvana/protection/protection_reference.proto\x1a\x17validate/validate.proto\"\xec\x01\n\x1fProtectionConvergenceAttachment\x12:\n\x04name\x18\x01 \x01(\tB,\xfa\x42)r\'\x10\x00\x18?2!^[a-z]?([a-z0-9-]*[a-z0-9]){0,1}$\x12?\n\x03ref\x18\x02 \x01(\x0b\x32(.prodvana.protection.ProtectionReferenceB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12L\n\tlifecycle\x18\x03 \x03(\x0b\x32(.prodvana.protection.ProtectionLifecycleB\x0f\xfa\x42\x0c\x92\x01\t\x08\x01\"\x05\x8a\x01\x02\x10\x01*Y\n\x0e\x41ttachmentType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x13\n\x0fRELEASE_CHANNEL\x10\x01\x12\x14\n\x10SERVICE_INSTANCE\x10\x02\x12\x0f\n\x0b\x43ONVERGENCE\x10\x03\x42OZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/protectionb\x06proto3')

_ATTACHMENTTYPE = DESCRIPTOR.enum_types_by_name['AttachmentType']
AttachmentType = enum_type_wrapper.EnumTypeWrapper(_ATTACHMENTTYPE)
UNKNOWN = 0
RELEASE_CHANNEL = 1
SERVICE_INSTANCE = 2
CONVERGENCE = 3


_PROTECTIONCONVERGENCEATTACHMENT = DESCRIPTOR.message_types_by_name['ProtectionConvergenceAttachment']
ProtectionConvergenceAttachment = _reflection.GeneratedProtocolMessageType('ProtectionConvergenceAttachment', (_message.Message,), {
  'DESCRIPTOR' : _PROTECTIONCONVERGENCEATTACHMENT,
  '__module__' : 'prodvana.protection.attachments_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.protection.ProtectionConvergenceAttachment)
  })
_sym_db.RegisterMessage(ProtectionConvergenceAttachment)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/protection'
  _PROTECTIONCONVERGENCEATTACHMENT.fields_by_name['name']._options = None
  _PROTECTIONCONVERGENCEATTACHMENT.fields_by_name['name']._serialized_options = b'\372B)r\'\020\000\030?2!^[a-z]?([a-z0-9-]*[a-z0-9]){0,1}$'
  _PROTECTIONCONVERGENCEATTACHMENT.fields_by_name['ref']._options = None
  _PROTECTIONCONVERGENCEATTACHMENT.fields_by_name['ref']._serialized_options = b'\372B\005\212\001\002\020\001'
  _PROTECTIONCONVERGENCEATTACHMENT.fields_by_name['lifecycle']._options = None
  _PROTECTIONCONVERGENCEATTACHMENT.fields_by_name['lifecycle']._serialized_options = b'\372B\014\222\001\t\010\001\"\005\212\001\002\020\001'
  _ATTACHMENTTYPE._serialized_start=374
  _ATTACHMENTTYPE._serialized_end=463
  _PROTECTIONCONVERGENCEATTACHMENT._serialized_start=136
  _PROTECTIONCONVERGENCEATTACHMENT._serialized_end=372
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/parameters.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.common_config import program_pb2 as prodvana_dot_common__config_dot_program__pb2
from prodvana.proto.prodvana.common_config import env_pb2 as prodvana_dot_common__config_dot_env__pb2
from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'prodvana/common_config/parameters.proto\x12\x16prodvana.common_config\x1a$prodvana/common_config/program.proto\x1a prodvana/common_config/env.proto\x1a\x17validate/validate.proto\"&\n\rProgramChange\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\"2\n\x19StringParameterDefinition\x12\x15\n\rdefault_value\x18\x01 \x01(\t\"\xc3\x02\n\x1e\x44ockerImageParameterDefinition\x12\x1c\n\x0b\x64\x65\x66\x61ult_tag\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12P\n\x13image_registry_info\x18\x02 \x01(\x0b\x32).prodvana.common_config.ImageRegistryInfoB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12^\n\x07\x63hanges\x18\x03 \x03(\x0b\x32>.prodvana.common_config.DockerImageParameterDefinition.ChangesB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x1aQ\n\x07\x43hanges\x12\x38\n\x07program\x18\x01 \x01(\x0b\x32%.prodvana.common_config.ProgramChangeH\x00\x42\x0c\n\x05oneof\x12\x03\xf8\x42\x01\"\x14\n\x12\x46ixedReplicaChange\"\xe5\x01\n\x16IntParameterDefinition\x12\x15\n\rdefault_value\x18\x01 \x01(\x03\x12V\n\x07\x63hanges\x18\x02 \x03(\x0b\x32\x36.prodvana.common_config.IntParameterDefinition.ChangesB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x1a\\\n\x07\x43hanges\x12\x43\n\rfixed_replica\x18\x01 \x01(\x0b\x32*.prodvana.common_config.FixedReplicaChangeH\x00\x42\x0c\n\x05oneof\x12\x03\xf8\x42\x01\"\x1b\n\x19SecretParameterDefinition\"\x81\x03\n\x13ParameterDefinition\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x43\n\x06string\x18\x03 \x01(\x0b\x32\x31.prodvana.common_config.StringParameterDefinitionH\x00\x12N\n\x0c\x64ocker_image\x18\x04 \x01(\x0b\x32\x36.prodvana.common_config.DockerImageParameterDefinitionH\x00\x12=\n\x03int\x18\x05 \x01(\x0b\x32..prodvana.common_config.IntParameterDefinitionH\x00\x12\x43\n\x06secret\x18\x06 \x01(\x0b\x32\x31.prodvana.common_config.SecretParameterDefinitionH\x00\x12\x10\n\x08required\x18\x07 \x01(\x08\x42\x13\n\x0c\x63onfig_oneof\x12\x03\xf8\x42\x01\"w\n\x14SecretParameterValue\x12\x14\n\nraw_secret\x18\x01 \x01(\tH\x00\x12\x34\n\nsecret_ref\x18\x02 \x01(\x0b\x32\x1e.prodvana.common_config.SecretH\x00\x42\x13\n\x0csecret_oneof\x12\x03\xf8\x42\x01\"\xcc\x01\n\x0eParameterValue\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x10\n\x06string\x18\x02 \x01(\tH\x00\x12\r\n\x03int\x18\x04 \x01(\x03H\x00\x12\x1a\n\x10\x64ocker_image_tag\x18\x05 \x01(\tH\x00\x12>\n\x06secret\x18\x06 \x01(\x0b\x32,.prodvana.common_config.SecretParameterValueH\x00\x42\x12\n\x0bvalue_oneof\x12\x03\xf8\x42\x01J\x04\x08\x03\x10\x04R\x0c\x64ocker_image\"b\n\x10ParametersConfig\x12N\n\nparameters\x18\x01 \x03(\x0b\x32+.prodvana.common_config.ParameterDefinitionB\r\xfa\x42\n\x92\x01\x07\"\x05\x8a\x01\x02\x10\x01\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')



_PROGRAMCHANGE = DESCRIPTOR.message_types_by_name['ProgramChange']
_STRINGPARAMETERDEFINITION = DESCRIPTOR.message_types_by_name['StringParameterDefinition']
_DOCKERIMAGEPARAMETERDEFINITION = DESCRIPTOR.message_types_by_name['DockerImageParameterDefinition']
_DOCKERIMAGEPARAMETERDEFINITION_CHANGES = _DOCKERIMAGEPARAMETERDEFINITION.nested_types_by_name['Changes']
_FIXEDREPLICACHANGE = DESCRIPTOR.message_types_by_name['FixedReplicaChange']
_INTPARAMETERDEFINITION = DESCRIPTOR.message_types_by_name['IntParameterDefinition']
_INTPARAMETERDEFINITION_CHANGES = _INTPARAMETERDEFINITION.nested_types_by_name['Changes']
_SECRETPARAMETERDEFINITION = DESCRIPTOR.message_types_by_name['SecretParameterDefinition']
_PARAMETERDEFINITION = DESCRIPTOR.message_types_by_name['ParameterDefinition']
_SECRETPARAMETERVALUE = DESCRIPTOR.message_types_by_name['SecretParameterValue']
_PARAMETERVALUE = DESCRIPTOR.message_types_by_name['ParameterValue']
_PARAMETERSCONFIG = DESCRIPTOR.message_types_by_name['ParametersConfig']
ProgramChange = _reflection.GeneratedProtocolMessageType('ProgramChange', (_message.Message,), {
  'DESCRIPTOR' : _PROGRAMCHANGE,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.ProgramChange)
  })
_sym_db.RegisterMessage(ProgramChange)

StringParameterDefinition = _reflection.GeneratedProtocolMessageType('StringParameterDefinition', (_message.Message,), {
  'DESCRIPTOR' : _STRINGPARAMETERDEFINITION,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.StringParameterDefinition)
  })
_sym_db.RegisterMessage(StringParameterDefinition)

DockerImageParameterDefinition = _reflection.GeneratedProtocolMessageType('DockerImageParameterDefinition', (_message.Message,), {

  'Changes' : _reflection.GeneratedProtocolMessageType('Changes', (_message.Message,), {
    'DESCRIPTOR' : _DOCKERIMAGEPARAMETERDEFINITION_CHANGES,
    '__module__' : 'prodvana.common_config.parameters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.common_config.DockerImageParameterDefinition.Changes)
    })
  ,
  'DESCRIPTOR' : _DOCKERIMAGEPARAMETERDEFINITION,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.DockerImageParameterDefinition)
  })
_sym_db.RegisterMessage(DockerImageParameterDefinition)
_sym_db.RegisterMessage(DockerImageParameterDefinition.Changes)

FixedReplicaChange = _reflection.GeneratedProtocolMessageType('FixedReplicaChange', (_message.Message,), {
  'DESCRIPTOR' : _FIXEDREPLICACHANGE,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.FixedReplicaChange)
  })
_sym_db.RegisterMessage(FixedReplicaChange)

IntParameterDefinition = _reflection.GeneratedProtocolMessageType('IntParameterDefinition', (_message.Message,), {

  'Changes' : _reflection.GeneratedProtocolMessageType('Changes', (_message.Message,), {
    'DESCRIPTOR' : _INTPARAMETERDEFINITION_CHANGES,
    '__module__' : 'prodvana.common_config.parameters_pb2'
    # @@protoc_insertion_point(class_scope:prodvana.common_config.IntParameterDefinition.Changes)
    })
  ,
  'DESCRIPTOR' : _INTPARAMETERDEFINITION,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.IntParameterDefinition)
  })
_sym_db.RegisterMessage(IntParameterDefinition)
_sym_db.RegisterMessage(IntParameterDefinition.Changes)

SecretParameterDefinition = _reflection.GeneratedProtocolMessageType('SecretParameterDefinition', (_message.Message,), {
  'DESCRIPTOR' : _SECRETPARAMETERDEFINITION,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.SecretParameterDefinition)
  })
_sym_db.RegisterMessage(SecretParameterDefinition)

ParameterDefinition = _reflection.GeneratedProtocolMessageType('ParameterDefinition', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERDEFINITION,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.ParameterDefinition)
  })
_sym_db.RegisterMessage(ParameterDefinition)

SecretParameterValue = _reflection.GeneratedProtocolMessageType('SecretParameterValue', (_message.Message,), {
  'DESCRIPTOR' : _SECRETPARAMETERVALUE,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.SecretParameterValue)
  })
_sym_db.RegisterMessage(SecretParameterValue)

ParameterValue = _reflection.GeneratedProtocolMessageType('ParameterValue', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERVALUE,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.ParameterValue)
  })
_sym_db.RegisterMessage(ParameterValue)

ParametersConfig = _reflection.GeneratedProtocolMessageType('ParametersConfig', (_message.Message,), {
  'DESCRIPTOR' : _PARAMETERSCONFIG,
  '__module__' : 'prodvana.common_config.parameters_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.ParametersConfig)
  })
_sym_db.RegisterMessage(ParametersConfig)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _PROGRAMCHANGE.fields_by_name['name']._options = None
  _PROGRAMCHANGE.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _DOCKERIMAGEPARAMETERDEFINITION_CHANGES.oneofs_by_name['oneof']._options = None
  _DOCKERIMAGEPARAMETERDEFINITION_CHANGES.oneofs_by_name['oneof']._serialized_options = b'\370B\001'
  _DOCKERIMAGEPARAMETERDEFINITION.fields_by_name['default_tag']._options = None
  _DOCKERIMAGEPARAMETERDEFINITION.fields_by_name['default_tag']._serialized_options = b'\372B\004r\002\020\001'
  _DOCKERIMAGEPARAMETERDEFINITION.fields_by_name['image_registry_info']._options = None
  _DOCKERIMAGEPARAMETERDEFINITION.fields_by_name['image_registry_info']._serialized_options = b'\372B\005\212\001\002\020\001'
  _DOCKERIMAGEPARAMETERDEFINITION.fields_by_name['changes']._options = None
  _DOCKERIMAGEPARAMETERDEFINITION.fields_by_name['changes']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _INTPARAMETERDEFINITION_CHANGES.oneofs_by_name['oneof']._options = None
  _INTPARAMETERDEFINITION_CHANGES.oneofs_by_name['oneof']._serialized_options = b'\370B\001'
  _INTPARAMETERDEFINITION.fields_by_name['changes']._options = None
  _INTPARAMETERDEFINITION.fields_by_name['changes']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _PARAMETERDEFINITION.oneofs_by_name['config_oneof']._options = None
  _PARAMETERDEFINITION.oneofs_by_name['config_oneof']._serialized_options = b'\370B\001'
  _PARAMETERDEFINITION.fields_by_name['name']._options = None
  _PARAMETERDEFINITION.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _SECRETPARAMETERVALUE.oneofs_by_name['secret_oneof']._options = None
  _SECRETPARAMETERVALUE.oneofs_by_name['secret_oneof']._serialized_options = b'\370B\001'
  _PARAMETERVALUE.oneofs_by_name['value_oneof']._options = None
  _PARAMETERVALUE.oneofs_by_name['value_oneof']._serialized_options = b'\370B\001'
  _PARAMETERVALUE.fields_by_name['name']._options = None
  _PARAMETERVALUE.fields_by_name['name']._serialized_options = b'\372B\004r\002\020\001'
  _PARAMETERSCONFIG.fields_by_name['parameters']._options = None
  _PARAMETERSCONFIG.fields_by_name['parameters']._serialized_options = b'\372B\n\222\001\007\"\005\212\001\002\020\001'
  _PROGRAMCHANGE._serialized_start=164
  _PROGRAMCHANGE._serialized_end=202
  _STRINGPARAMETERDEFINITION._serialized_start=204
  _STRINGPARAMETERDEFINITION._serialized_end=254
  _DOCKERIMAGEPARAMETERDEFINITION._serialized_start=257
  _DOCKERIMAGEPARAMETERDEFINITION._serialized_end=580
  _DOCKERIMAGEPARAMETERDEFINITION_CHANGES._serialized_start=499
  _DOCKERIMAGEPARAMETERDEFINITION_CHANGES._serialized_end=580
  _FIXEDREPLICACHANGE._serialized_start=582
  _FIXEDREPLICACHANGE._serialized_end=602
  _INTPARAMETERDEFINITION._serialized_start=605
  _INTPARAMETERDEFINITION._serialized_end=834
  _INTPARAMETERDEFINITION_CHANGES._serialized_start=742
  _INTPARAMETERDEFINITION_CHANGES._serialized_end=834
  _SECRETPARAMETERDEFINITION._serialized_start=836
  _SECRETPARAMETERDEFINITION._serialized_end=863
  _PARAMETERDEFINITION._serialized_start=866
  _PARAMETERDEFINITION._serialized_end=1251
  _SECRETPARAMETERVALUE._serialized_start=1253
  _SECRETPARAMETERVALUE._serialized_end=1372
  _PARAMETERVALUE._serialized_start=1375
  _PARAMETERVALUE._serialized_end=1579
  _PARAMETERSCONFIG._serialized_start=1581
  _PARAMETERSCONFIG._serialized_end=1679
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/events/types.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.prodvana.desired_state.model import desired_state_pb2 as prodvana_dot_desired__state_dot_model_dot_desired__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bprodvana/events/types.proto\x12\x0fprodvana.events\x1a\x30prodvana/desired_state/model/desired_state.proto\"\xd0\x01\n\x14SetDesiredStateEvent\x12\x34\n\x02id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x18\n\x10\x64\x65sired_state_id\x18\x03 \x01(\t\x12\x1d\n\x15root_desired_state_id\x18\x04 \x01(\t\x12\x34\n\x07\x64\x65sired\x18\x02 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x13\n\x0bis_rollback\x18\x05 \x01(\x08\"\xc3\x03\n\x13SetTargetStateEvent\x12\x34\n\x02id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x18\n\x10\x64\x65sired_state_id\x18\x08 \x01(\t\x12\x1d\n\x15root_desired_state_id\x18\t \x01(\t\x12\x33\n\x06target\x18\x02 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x34\n\x07\x64\x65sired\x18\x03 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x34\n\x07\x63urrent\x18\x04 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x18\n\x10is_auto_rollback\x18\x05 \x01(\x08\x12\x34\n\x06status\x18\x06 \x01(\x0e\x32$.prodvana.desired_state.model.Status\x12L\n\x13status_explanations\x18\x07 \x03(\x0b\x32/.prodvana.desired_state.model.StatusExplanation\"\x95\x03\n\x15\x41pplyTargetStateEvent\x12\x34\n\x02id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x18\n\x10\x64\x65sired_state_id\x18\x06 \x01(\t\x12\x1d\n\x15root_desired_state_id\x18\x07 \x01(\t\x12\x33\n\x06target\x18\x02 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x34\n\x07\x63urrent\x18\x03 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x18\n\x10is_auto_rollback\x18\x04 \x01(\x08\x12\x42\n\x06result\x18\x05 \x01(\x0e\x32\x32.prodvana.events.ApplyTargetStateEvent.ApplyResult\x12\r\n\x05\x65rror\x18\x08 \x01(\t\"5\n\x0b\x41pplyResult\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tSUCCEEDED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\"\xb0\x01\n\x10ProgramExitEvent\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0b\n\x03pod\x18\x02 \x01(\t\x12\x0f\n\x07program\x18\x03 \x01(\t\x12\x15\n\rrestart_count\x18\x04 \x01(\x05\x12\x0e\n\x06reason\x18\x05 \x01(\t\x12\x15\n\rkilled_reason\x18\t \x01(\t\x12\x11\n\texit_code\x18\x06 \x01(\x05\x12\x0e\n\x06signal\x18\x07 \x01(\x05J\x04\x08\x08\x10\tR\x04logs\"S\n\x15\x44\x65liveryProgressEvent\x12:\n\x05state\x18\x01 \x01(\x0b\x32+.prodvana.desired_state.model.DeliveryState\"w\n\x1c\x44\x65liveryManualPromotionEvent\x12:\n\x05state\x18\x01 \x01(\x0b\x32+.prodvana.desired_state.model.DeliveryState\x12\r\n\x05stage\x18\x02 \x01(\x03\x12\x0c\n\x04\x66ull\x18\x03 \x01(\x08\"h\n\x13ManualApprovalEvent\x12\x42\n\x06status\x18\x01 \x01(\x0e\x32\x32.prodvana.desired_state.model.ManualApprovalStatus\x12\r\n\x05topic\x18\x02 \x01(\t\"\\\n\x18\x43ustomTaskExecutionEvent\x12\x12\n\nsuccessful\x18\x01 \x01(\x08\x12\x10\n\x08\x61ttempts\x18\x02 \x01(\x05\x12\x0e\n\x06reason\x18\x03 \x01(\tJ\x04\x08\x04\x10\x05R\x04logs\"K\n\rRuntimeObject\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\"\xe4\x02\n\x12RuntimeUpdateEvent\x12\x41\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x31.prodvana.events.RuntimeUpdateEvent.RuntimeAction\x12.\n\x06object\x18\x02 \x01(\x0b\x32\x1e.prodvana.events.RuntimeObject\x12\x41\n\x06status\x18\x03 \x01(\x0e\x32\x31.prodvana.events.RuntimeUpdateEvent.RuntimeStatus\"D\n\rRuntimeAction\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x14\n\x10\x43REATE_OR_UPDATE\x10\x01\x12\x10\n\x0cWAIT_HEALTHY\x10\x02\"R\n\rRuntimeStatus\x12\x1a\n\x16RUNTIME_STATUS_UNKNOWN\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x12\x0b\n\x07\x46\x41ILURE\x10\x03\"\xab\x04\n\x1d\x44\x65siredStateStatusChangeEvent\x12\x34\n\x02id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x18\n\x10\x64\x65sired_state_id\x18\x02 \x01(\t\x12\x1d\n\x15root_desired_state_id\x18\x03 \x01(\t\x12\x38\n\nold_status\x18\x04 \x01(\x0e\x32$.prodvana.desired_state.model.Status\x12\x38\n\nnew_status\x18\x05 \x01(\x0e\x32$.prodvana.desired_state.model.Status\x12\x34\n\x07\x64\x65sired\x18\x06 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x33\n\x06target\x18\x07 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x36\n\told_state\x18\x08 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x36\n\tnew_state\x18\t \x01(\x0b\x32#.prodvana.desired_state.model.State\x12L\n\x13status_explanations\x18\n \x03(\x0b\x32/.prodvana.desired_state.model.StatusExplanation\"\xc6\x04\n\x18KeyDeliveryDecisionEvent\x12\x34\n\x02id\x18\x01 \x01(\x0b\x32(.prodvana.desired_state.model.Identifier\x12\x18\n\x10\x64\x65sired_state_id\x18\x02 \x01(\t\x12\x1d\n\x15root_desired_state_id\x18\x03 \x01(\t\x12\x44\n\x08\x64\x65\x63ision\x18\x04 \x01(\x0e\x32\x32.prodvana.events.KeyDeliveryDecisionEvent.Decision\x12\x13\n\x0b\x65xplanation\x18\x05 \x01(\t\x12\x34\n\x06status\x18\x06 \x01(\x0e\x32$.prodvana.desired_state.model.Status\x12\x34\n\x07\x64\x65sired\x18\x07 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x33\n\x06target\x18\x08 \x01(\x0b\x32#.prodvana.desired_state.model.State\x12\x34\n\x07\x63urrent\x18\t \x01(\x0b\x32#.prodvana.desired_state.model.State\x12L\n\x13status_explanations\x18\n \x03(\x0b\x32/.prodvana.desired_state.model.StatusExplanation\";\n\x08\x44\x65\x63ision\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x16\n\x12ROLLBACK_INITIATED\x10\x01\x12\n\n\x06\x46\x41ILED\x10\x02\"\xa7\x06\n\x0c\x45ventDetails\x12\x42\n\x11set_desired_state\x18\x01 \x01(\x0b\x32%.prodvana.events.SetDesiredStateEventH\x00\x12@\n\x10set_target_state\x18\x02 \x01(\x0b\x32$.prodvana.events.SetTargetStateEventH\x00\x12\x39\n\x0cprogram_exit\x18\x03 \x01(\x0b\x32!.prodvana.events.ProgramExitEventH\x00\x12\x44\n\x12\x61pply_target_state\x18\x04 \x01(\x0b\x32&.prodvana.events.ApplyTargetStateEventH\x00\x12?\n\x0fmanual_approval\x18\x06 \x01(\x0b\x32$.prodvana.events.ManualApprovalEventH\x00\x12J\n\x15\x63ustom_task_execution\x18\x07 \x01(\x0b\x32).prodvana.events.CustomTaskExecutionEventH\x00\x12=\n\x0eruntime_update\x18\x08 \x01(\x0b\x32#.prodvana.events.RuntimeUpdateEventH\x00\x12\x43\n\x11\x64\x65livery_progress\x18\t \x01(\x0b\x32&.prodvana.events.DeliveryProgressEventH\x00\x12K\n\x12\x64\x65livery_promotion\x18\n \x01(\x0b\x32-.prodvana.events.DeliveryManualPromotionEventH\x00\x12U\n\x1b\x64\x65sired_state_status_change\x18\x0b \x01(\x0b\x32..prodvana.events.DesiredStateStatusChangeEventH\x00\x12J\n\x15key_delivery_decision\x18\x0c \x01(\x0b\x32).prodvana.events.KeyDeliveryDecisionEventH\x00\x42\t\n\x07\x64\x65tailsJ\x04\x08\x05\x10\x06*\xab\x02\n\tEventType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x15\n\x11SET_DESIRED_STATE\x10\x01\x12\x14\n\x10SET_TARGET_STATE\x10\x02\x12\x10\n\x0cPROGRAM_EXIT\x10\x03\x12\x16\n\x12\x41PPLY_TARGET_STATE\x10\x04\x12\x13\n\x0fMANUAL_APPROVAL\x10\x06\x12\x19\n\x15\x43USTOM_TASK_EXECUTION\x10\x07\x12\x12\n\x0eRUNTIME_UPDATE\x10\x08\x12\x15\n\x11\x44\x45LIVERY_PROGRESS\x10\t\x12\x1d\n\x19\x44\x45LIVERY_MANUAL_PROMOTION\x10\n\x12\x1f\n\x1b\x44\x45SIRED_STATE_STATUS_CHANGE\x10\x0b\x12\x19\n\x15KEY_DELIVERY_DECISION\x10\x0c\"\x04\x08\x05\x10\x05\x42KZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/eventsb\x06proto3')

_EVENTTYPE = DESCRIPTOR.enum_types_by_name['EventType']
EventType = enum_type_wrapper.EnumTypeWrapper(_EVENTTYPE)
UNKNOWN = 0
SET_DESIRED_STATE = 1
SET_TARGET_STATE = 2
PROGRAM_EXIT = 3
APPLY_TARGET_STATE = 4
MANUAL_APPROVAL = 6
CUSTOM_TASK_EXECUTION = 7
RUNTIME_UPDATE = 8
DELIVERY_PROGRESS = 9
DELIVERY_MANUAL_PROMOTION = 10
DESIRED_STATE_STATUS_CHANGE = 11
KEY_DELIVERY_DECISION = 12


_SETDESIREDSTATEEVENT = DESCRIPTOR.message_types_by_name['SetDesiredStateEvent']
_SETTARGETSTATEEVENT = DESCRIPTOR.message_types_by_name['SetTargetStateEvent']
_APPLYTARGETSTATEEVENT = DESCRIPTOR.message_types_by_name['ApplyTargetStateEvent']
_PROGRAMEXITEVENT = DESCRIPTOR.message_types_by_name['ProgramExitEvent']
_DELIVERYPROGRESSEVENT = DESCRIPTOR.message_types_by_name['DeliveryProgressEvent']
_DELIVERYMANUALPROMOTIONEVENT = DESCRIPTOR.message_types_by_name['DeliveryManualPromotionEvent']
_MANUALAPPROVALEVENT = DESCRIPTOR.message_types_by_name['ManualApprovalEvent']
_CUSTOMTASKEXECUTIONEVENT = DESCRIPTOR.message_types_by_name['CustomTaskExecutionEvent']
_RUNTIMEOBJECT = DESCRIPTOR.message_types_by_name['RuntimeObject']
_RUNTIMEUPDATEEVENT = DESCRIPTOR.message_types_by_name['RuntimeUpdateEvent']
_DESIREDSTATESTATUSCHANGEEVENT = DESCRIPTOR.message_types_by_name['DesiredStateStatusChangeEvent']
_KEYDELIVERYDECISIONEVENT = DESCRIPTOR.message_types_by_name['KeyDeliveryDecisionEvent']
_EVENTDETAILS = DESCRIPTOR.message_types_by_name['EventDetails']
_APPLYTARGETSTATEEVENT_APPLYRESULT = _APPLYTARGETSTATEEVENT.enum_types_by_name['ApplyResult']
_RUNTIMEUPDATEEVENT_RUNTIMEACTION = _RUNTIMEUPDATEEVENT.enum_types_by_name['RuntimeAction']
_RUNTIMEUPDATEEVENT_RUNTIMESTATUS = _RUNTIMEUPDATEEVENT.enum_types_by_name['RuntimeStatus']
_KEYDELIVERYDECISIONEVENT_DECISION = _KEYDELIVERYDECISIONEVENT.enum_types_by_name['Decision']
SetDesiredStateEvent = _reflection.GeneratedProtocolMessageType('SetDesiredStateEvent', (_message.Message,), {
  'DESCRIPTOR' : _SETDESIREDSTATEEVENT,
  '__module__' : 'prodvana.events.types_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.events.SetDesiredStateEvent)
  })
_sym_db.RegisterMessage(SetDesiredStateEvent)

SetTargetStateEvent = _reflection.GeneratedProtocolMessageType('SetTargetStateEvent', (_message.Message,), {
  'DESCRIPTOR' : _SETTARGETSTATEEVENT,
  '__module__' : 'prodvana.events.types_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.events.SetTargetStateEvent)
  })
_sym_db.RegisterMessage(SetTargetStateEvent)

ApplyTargetStateEvent = _reflection.GeneratedProtocolMessageType('ApplyTargetStateEvent', (_message.Message,), {
  'DESCRIPTOR' : _APPLYTARGETSTATEEVENT,
  '__module__' : 'prodvana.events.types_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.events.ApplyTargetStateEvent)
  })
_sym_db.RegisterMessage(ApplyTargetStateEvent)

ProgramExitEvent = _reflection.GeneratedProtocolMessageType('ProgramExitEvent', (_message.Message,), {
  'DESCRIPTOR' : _PROGRAMEXITEVENT,
  '__module__' : 'prodvana.events.types_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.events.ProgramExitEvent)
  })
_sym_db.RegisterMessage(ProgramExitEvent)

DeliveryProgressEvent = _reflection.GeneratedProtocolMessageType('DeliveryProgressEvent', (_message.Message,), {
  'DESCRIPTOR' : _DELIVERYPROGRESSEVENT,
  '__module__' : 'prodvana.events.types_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.events.DeliveryProgressEvent)
  })
_sym_db.RegisterMessage(DeliveryProgressEvent)

DeliveryManualPromotionEvent = _reflection.GeneratedProtocolMessageType('DeliveryManualPromotionEvent', (_message.Message,), {
  'DESCRIPTOR' : _DELIVERYMANUALPROMOTIONEVENT,
  '__module__' : 'prodvana.events.types_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.events.DeliveryManualPromotionEvent)
  })
_sym_db.RegisterMessage(DeliveryManualPromotionEvent)

ManualApprovalEvent = _reflection.GeneratedProtocolMessageType('ManualApprovalEvent', (_message.Message,), {
  'DESCRIPTOR' : _MANUALAPPROVALEVENT,
  '__module__' : 'prodvana.events.types_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.events.ManualApprovalEvent)
  })
_sym_db.RegisterMessage(ManualApprovalEvent)

CustomTaskExecutionEvent = _reflection.GeneratedProtocolMessageType('CustomTaskExecutionEvent', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMTASKEXECUTIONEVENT,
  '__module__' : 'prodvana.events.types_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.events.CustomTaskExecutionEvent)
  })
_sym_db.RegisterMessage(CustomTaskExecutionEvent)

RuntimeObject = _reflection.GeneratedProtocolMessageType('RuntimeObject', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMEOBJECT,
  '__module__' : 'prodvana.events.types_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.events.RuntimeObject)
  })
_sym_db.RegisterMessage(RuntimeObject)

RuntimeUpdateEvent = _reflection.GeneratedProtocolMessageType('RuntimeUpdateEvent', (_message.Message,), {
  'DESCRIPTOR' : _RUNTIMEUPDATEEVENT,
  '__module__' : 'prodvana.events.types_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.events.RuntimeUpdateEvent)
  })
_sym_db.RegisterMessage(RuntimeUpdateEvent)

DesiredStateStatusChangeEvent = _reflection.GeneratedProtocolMessageType('DesiredStateStatusChangeEvent', (_message.Message,), {
  'DESCRIPTOR' : _DESIREDSTATESTATUSCHANGEEVENT,
  '__module__' : 'prodvana.events.types_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.events.DesiredStateStatusChangeEvent)
  })
_sym_db.RegisterMessage(DesiredStateStatusChangeEvent)

KeyDeliveryDecisionEvent = _reflection.GeneratedProtocolMessageType('KeyDeliveryDecisionEvent', (_message.Message,), {
  'DESCRIPTOR' : _KEYDELIVERYDECISIONEVENT,
  '__module__' : 'prodvana.events.types_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.events.KeyDeliveryDecisionEvent)
  })
_sym_db.RegisterMessage(KeyDeliveryDecisionEvent)

EventDetails = _reflection.GeneratedProtocolMessageType('EventDetails', (_message.Message,), {
  'DESCRIPTOR' : _EVENTDETAILS,
  '__module__' : 'prodvana.events.types_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.events.EventDetails)
  })
_sym_db.RegisterMessage(EventDetails)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZIgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/events'
  _EVENTTYPE._serialized_start=4146
  _EVENTTYPE._serialized_end=4445
  _SETDESIREDSTATEEVENT._serialized_start=99
  _SETDESIREDSTATEEVENT._serialized_end=307
  _SETTARGETSTATEEVENT._serialized_start=310
  _SETTARGETSTATEEVENT._serialized_end=761
  _APPLYTARGETSTATEEVENT._serialized_start=764
  _APPLYTARGETSTATEEVENT._serialized_end=1169
  _APPLYTARGETSTATEEVENT_APPLYRESULT._serialized_start=1116
  _APPLYTARGETSTATEEVENT_APPLYRESULT._serialized_end=1169
  _PROGRAMEXITEVENT._serialized_start=1172
  _PROGRAMEXITEVENT._serialized_end=1348
  _DELIVERYPROGRESSEVENT._serialized_start=1350
  _DELIVERYPROGRESSEVENT._serialized_end=1433
  _DELIVERYMANUALPROMOTIONEVENT._serialized_start=1435
  _DELIVERYMANUALPROMOTIONEVENT._serialized_end=1554
  _MANUALAPPROVALEVENT._serialized_start=1556
  _MANUALAPPROVALEVENT._serialized_end=1660
  _CUSTOMTASKEXECUTIONEVENT._serialized_start=1662
  _CUSTOMTASKEXECUTIONEVENT._serialized_end=1754
  _RUNTIMEOBJECT._serialized_start=1756
  _RUNTIMEOBJECT._serialized_end=1831
  _RUNTIMEUPDATEEVENT._serialized_start=1834
  _RUNTIMEUPDATEEVENT._serialized_end=2190
  _RUNTIMEUPDATEEVENT_RUNTIMEACTION._serialized_start=2038
  _RUNTIMEUPDATEEVENT_RUNTIMEACTION._serialized_end=2106
  _RUNTIMEUPDATEEVENT_RUNTIMESTATUS._serialized_start=2108
  _RUNTIMEUPDATEEVENT_RUNTIMESTATUS._serialized_end=2190
  _DESIREDSTATESTATUSCHANGEEVENT._serialized_start=2193
  _DESIREDSTATESTATUSCHANGEEVENT._serialized_end=2748
  _KEYDELIVERYDECISIONEVENT._serialized_start=2751
  _KEYDELIVERYDECISIONEVENT._serialized_end=3333
  _KEYDELIVERYDECISIONEVENT_DECISION._serialized_start=3274
  _KEYDELIVERYDECISIONEVENT_DECISION._serialized_end=3333
  _EVENTDETAILS._serialized_start=3336
  _EVENTDETAILS._serialized_end=4143
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import prodvana.proto.prodvana.desired_state.model.desired_state_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _EventType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _EventTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EventType.ValueType], builtins.type):  # noqa: F821
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _EventType.ValueType  # 0
    SET_DESIRED_STATE: _EventType.ValueType  # 1
    """when a user sets a new desired state"""
    SET_TARGET_STATE: _EventType.ValueType  # 2
    """when dyanmic delivery sets a new target state as part of convergence. A desired state convergence
    involves a series of SET_TARGET_STATE event, one per each entity managed as part of convergence.
    """
    PROGRAM_EXIT: _EventType.ValueType  # 3
    APPLY_TARGET_STATE: _EventType.ValueType  # 4
    """When dynamic delivery materializes a target state to physical infrastructure as part of convergence.
    Each SET_TARGET_STATE is followed by one or more APPLY_TARGET_STATE, unless convergence is aborted.
    """
    MANUAL_APPROVAL: _EventType.ValueType  # 6
    CUSTOM_TASK_EXECUTION: _EventType.ValueType  # 7
    RUNTIME_UPDATE: _EventType.ValueType  # 8
    """generic runtime events when more specific event types are not available."""
    DELIVERY_PROGRESS: _EventType.ValueType  # 9
    DELIVERY_MANUAL_PROMOTION: _EventType.ValueType  # 10
    DESIRED_STATE_STATUS_CHANGE: _EventType.ValueType  # 11
    KEY_DELIVERY_DECISION: _EventType.ValueType  # 12

class EventType(_EventType, metaclass=_EventTypeEnumTypeWrapper): ...

UNKNOWN: EventType.ValueType  # 0
SET_DESIRED_STATE: EventType.ValueType  # 1
"""when a user sets a new desired state"""
SET_TARGET_STATE: EventType.ValueType  # 2
"""when dyanmic delivery sets a new target state as part of convergence. A desired state convergence
involves a series of SET_TARGET_STATE event, one per each entity managed as part of convergence.
"""
PROGRAM_EXIT: EventType.ValueType  # 3
APPLY_TARGET_STATE: EventType.ValueType  # 4
"""When dynamic delivery materializes a target state to physical infrastructure as part of convergence.
Each SET_TARGET_STATE is followed by one or more APPLY_TARGET_STATE, unless convergence is aborted.
"""
MANUAL_APPROVAL: EventType.ValueType  # 6
CUSTOM_TASK_EXECUTION: EventType.ValueType  # 7
RUNTIME_UPDATE: EventType.ValueType  # 8
"""generic runtime events when more specific event types are not available."""
DELIVERY_PROGRESS: EventType.ValueType  # 9
DELIVERY_MANUAL_PROMOTION: EventType.ValueType  # 10
DESIRED_STATE_STATUS_CHANGE: EventType.ValueType  # 11
KEY_DELIVERY_DECISION: EventType.ValueType  # 12
global___EventType = EventType

class SetDesiredStateEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ROOT_DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    DESIRED_FIELD_NUMBER: builtins.int
    IS_ROLLBACK_FIELD_NUMBER: builtins.int
    @property
    def id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    desired_state_id: builtins.str
    root_desired_state_id: builtins.str
    @property
    def desired(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    is_rollback: builtins.bool
    def __init__(
        self,
        *,
        id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        desired_state_id: builtins.str = ...,
        root_desired_state_id: builtins.str = ...,
        desired: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        is_rollback: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["desired", b"desired", "id", b"id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired", b"desired", "desired_state_id", b"desired_state_id", "id", b"id", "is_rollback", b"is_rollback", "root_desired_state_id", b"root_desired_state_id"]) -> None: ...

global___SetDesiredStateEvent = SetDesiredStateEvent

class SetTargetStateEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ROOT_DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    DESIRED_FIELD_NUMBER: builtins.int
    CURRENT_FIELD_NUMBER: builtins.int
    IS_AUTO_ROLLBACK_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    STATUS_EXPLANATIONS_FIELD_NUMBER: builtins.int
    @property
    def id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    desired_state_id: builtins.str
    root_desired_state_id: builtins.str
    @property
    def target(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State:
        """state that prodvana runtime will immediately converge towards"""
    @property
    def desired(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State:
        """final desired state that this entity should eventually get to"""
    @property
    def current(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State:
        """current state for this entity before setting target state"""
    is_auto_rollback: builtins.bool
    """whether this is part of an automated rollback action"""
    status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType
    """status and explanations at the time of SetTargetState"""
    @property
    def status_explanations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation]: ...
    def __init__(
        self,
        *,
        id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        desired_state_id: builtins.str = ...,
        root_desired_state_id: builtins.str = ...,
        target: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        desired: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        current: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        is_auto_rollback: builtins.bool = ...,
        status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType = ...,
        status_explanations: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["current", b"current", "desired", b"desired", "id", b"id", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["current", b"current", "desired", b"desired", "desired_state_id", b"desired_state_id", "id", b"id", "is_auto_rollback", b"is_auto_rollback", "root_desired_state_id", b"root_desired_state_id", "status", b"status", "status_explanations", b"status_explanations", "target", b"target"]) -> None: ...

global___SetTargetStateEvent = SetTargetStateEvent

class ApplyTargetStateEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ApplyResult:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ApplyResultEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ApplyTargetStateEvent._ApplyResult.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: ApplyTargetStateEvent._ApplyResult.ValueType  # 0
        SUCCEEDED: ApplyTargetStateEvent._ApplyResult.ValueType  # 1
        FAILED: ApplyTargetStateEvent._ApplyResult.ValueType  # 2

    class ApplyResult(_ApplyResult, metaclass=_ApplyResultEnumTypeWrapper): ...
    UNKNOWN: ApplyTargetStateEvent.ApplyResult.ValueType  # 0
    SUCCEEDED: ApplyTargetStateEvent.ApplyResult.ValueType  # 1
    FAILED: ApplyTargetStateEvent.ApplyResult.ValueType  # 2

    ID_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ROOT_DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    CURRENT_FIELD_NUMBER: builtins.int
    IS_AUTO_ROLLBACK_FIELD_NUMBER: builtins.int
    RESULT_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    @property
    def id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    desired_state_id: builtins.str
    root_desired_state_id: builtins.str
    @property
    def target(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State:
        """state that prodvana runtime will immediately converge towards"""
    @property
    def current(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State:
        """current state for this entity before setting target state"""
    is_auto_rollback: builtins.bool
    """whether this is part of an automated rollback action"""
    result: global___ApplyTargetStateEvent.ApplyResult.ValueType
    error: builtins.str
    """set if result = FAILED"""
    def __init__(
        self,
        *,
        id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        desired_state_id: builtins.str = ...,
        root_desired_state_id: builtins.str = ...,
        target: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        current: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        is_auto_rollback: builtins.bool = ...,
        result: global___ApplyTargetStateEvent.ApplyResult.ValueType = ...,
        error: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["current", b"current", "id", b"id", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["current", b"current", "desired_state_id", b"desired_state_id", "error", b"error", "id", b"id", "is_auto_rollback", b"is_auto_rollback", "result", b"result", "root_desired_state_id", b"root_desired_state_id", "target", b"target"]) -> None: ...

global___ApplyTargetStateEvent = ApplyTargetStateEvent

class ProgramExitEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_FIELD_NUMBER: builtins.int
    POD_FIELD_NUMBER: builtins.int
    PROGRAM_FIELD_NUMBER: builtins.int
    RESTART_COUNT_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    KILLED_REASON_FIELD_NUMBER: builtins.int
    EXIT_CODE_FIELD_NUMBER: builtins.int
    SIGNAL_FIELD_NUMBER: builtins.int
    namespace: builtins.str
    pod: builtins.str
    program: builtins.str
    """in k8s, this is container name"""
    restart_count: builtins.int
    reason: builtins.str
    """reason why process exited"""
    killed_reason: builtins.str
    """if killed, this is the reason why it was killed (best effort)"""
    exit_code: builtins.int
    """if 0, this is a successful exit."""
    signal: builtins.int
    """signal used to terminate this process, if any"""
    def __init__(
        self,
        *,
        namespace: builtins.str = ...,
        pod: builtins.str = ...,
        program: builtins.str = ...,
        restart_count: builtins.int = ...,
        reason: builtins.str = ...,
        killed_reason: builtins.str = ...,
        exit_code: builtins.int = ...,
        signal: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exit_code", b"exit_code", "killed_reason", b"killed_reason", "namespace", b"namespace", "pod", b"pod", "program", b"program", "reason", b"reason", "restart_count", b"restart_count", "signal", b"signal"]) -> None: ...

global___ProgramExitEvent = ProgramExitEvent

class DeliveryProgressEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    @property
    def state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DeliveryState: ...
    def __init__(
        self,
        *,
        state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DeliveryState | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["state", b"state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["state", b"state"]) -> None: ...

global___DeliveryProgressEvent = DeliveryProgressEvent

class DeliveryManualPromotionEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    STAGE_FIELD_NUMBER: builtins.int
    FULL_FIELD_NUMBER: builtins.int
    @property
    def state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DeliveryState: ...
    stage: builtins.int
    full: builtins.bool
    def __init__(
        self,
        *,
        state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.DeliveryState | None = ...,
        stage: builtins.int = ...,
        full: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["state", b"state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["full", b"full", "stage", b"stage", "state", b"state"]) -> None: ...

global___DeliveryManualPromotionEvent = DeliveryManualPromotionEvent

class ManualApprovalEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ManualApprovalStatus.ValueType
    """Approved/rejected?"""
    topic: builtins.str
    """Actor etc ..."""
    def __init__(
        self,
        *,
        status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.ManualApprovalStatus.ValueType = ...,
        topic: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["status", b"status", "topic", b"topic"]) -> None: ...

global___ManualApprovalEvent = ManualApprovalEvent

class CustomTaskExecutionEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESSFUL_FIELD_NUMBER: builtins.int
    ATTEMPTS_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    successful: builtins.bool
    attempts: builtins.int
    reason: builtins.str
    """Why did this job exit/fail?"""
    def __init__(
        self,
        *,
        successful: builtins.bool = ...,
        attempts: builtins.int = ...,
        reason: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["attempts", b"attempts", "reason", b"reason", "successful", b"successful"]) -> None: ...

global___CustomTaskExecutionEvent = CustomTaskExecutionEvent

class RuntimeObject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    name: builtins.str
    """name of object as it appears in the runtime layer"""
    kind: builtins.str
    namespace: builtins.str
    """optional, depends on if runtime has support for it"""
    url: builtins.str
    """optional, depends on if there is a unique URL to view this object."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        kind: builtins.str = ...,
        namespace: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kind", b"kind", "name", b"name", "namespace", b"namespace", "url", b"url"]) -> None: ...

global___RuntimeObject = RuntimeObject

class RuntimeUpdateEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _RuntimeAction:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RuntimeActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RuntimeUpdateEvent._RuntimeAction.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: RuntimeUpdateEvent._RuntimeAction.ValueType  # 0
        CREATE_OR_UPDATE: RuntimeUpdateEvent._RuntimeAction.ValueType  # 1
        WAIT_HEALTHY: RuntimeUpdateEvent._RuntimeAction.ValueType  # 2

    class RuntimeAction(_RuntimeAction, metaclass=_RuntimeActionEnumTypeWrapper): ...
    UNKNOWN: RuntimeUpdateEvent.RuntimeAction.ValueType  # 0
    CREATE_OR_UPDATE: RuntimeUpdateEvent.RuntimeAction.ValueType  # 1
    WAIT_HEALTHY: RuntimeUpdateEvent.RuntimeAction.ValueType  # 2

    class _RuntimeStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _RuntimeStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RuntimeUpdateEvent._RuntimeStatus.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        RUNTIME_STATUS_UNKNOWN: RuntimeUpdateEvent._RuntimeStatus.ValueType  # 0
        PENDING: RuntimeUpdateEvent._RuntimeStatus.ValueType  # 1
        SUCCESS: RuntimeUpdateEvent._RuntimeStatus.ValueType  # 2
        FAILURE: RuntimeUpdateEvent._RuntimeStatus.ValueType  # 3

    class RuntimeStatus(_RuntimeStatus, metaclass=_RuntimeStatusEnumTypeWrapper): ...
    RUNTIME_STATUS_UNKNOWN: RuntimeUpdateEvent.RuntimeStatus.ValueType  # 0
    PENDING: RuntimeUpdateEvent.RuntimeStatus.ValueType  # 1
    SUCCESS: RuntimeUpdateEvent.RuntimeStatus.ValueType  # 2
    FAILURE: RuntimeUpdateEvent.RuntimeStatus.ValueType  # 3

    ACTION_FIELD_NUMBER: builtins.int
    OBJECT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    action: global___RuntimeUpdateEvent.RuntimeAction.ValueType
    @property
    def object(self) -> global___RuntimeObject: ...
    status: global___RuntimeUpdateEvent.RuntimeStatus.ValueType
    def __init__(
        self,
        *,
        action: global___RuntimeUpdateEvent.RuntimeAction.ValueType = ...,
        object: global___RuntimeObject | None = ...,
        status: global___RuntimeUpdateEvent.RuntimeStatus.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["object", b"object"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "object", b"object", "status", b"status"]) -> None: ...

global___RuntimeUpdateEvent = RuntimeUpdateEvent

class DesiredStateStatusChangeEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ROOT_DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    OLD_STATUS_FIELD_NUMBER: builtins.int
    NEW_STATUS_FIELD_NUMBER: builtins.int
    DESIRED_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    OLD_STATE_FIELD_NUMBER: builtins.int
    NEW_STATE_FIELD_NUMBER: builtins.int
    STATUS_EXPLANATIONS_FIELD_NUMBER: builtins.int
    @property
    def id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    desired_state_id: builtins.str
    root_desired_state_id: builtins.str
    old_status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType
    new_status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType
    @property
    def desired(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def target(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def old_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def new_state(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def status_explanations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation]: ...
    def __init__(
        self,
        *,
        id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        desired_state_id: builtins.str = ...,
        root_desired_state_id: builtins.str = ...,
        old_status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType = ...,
        new_status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType = ...,
        desired: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        target: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        old_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        new_state: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        status_explanations: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["desired", b"desired", "id", b"id", "new_state", b"new_state", "old_state", b"old_state", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired", b"desired", "desired_state_id", b"desired_state_id", "id", b"id", "new_state", b"new_state", "new_status", b"new_status", "old_state", b"old_state", "old_status", b"old_status", "root_desired_state_id", b"root_desired_state_id", "status_explanations", b"status_explanations", "target", b"target"]) -> None: ...

global___DesiredStateStatusChangeEvent = DesiredStateStatusChangeEvent

class KeyDeliveryDecisionEvent(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Decision:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _DecisionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[KeyDeliveryDecisionEvent._Decision.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: KeyDeliveryDecisionEvent._Decision.ValueType  # 0
        ROLLBACK_INITIATED: KeyDeliveryDecisionEvent._Decision.ValueType  # 1
        FAILED: KeyDeliveryDecisionEvent._Decision.ValueType  # 2

    class Decision(_Decision, metaclass=_DecisionEnumTypeWrapper): ...
    UNKNOWN: KeyDeliveryDecisionEvent.Decision.ValueType  # 0
    ROLLBACK_INITIATED: KeyDeliveryDecisionEvent.Decision.ValueType  # 1
    FAILED: KeyDeliveryDecisionEvent.Decision.ValueType  # 2

    ID_FIELD_NUMBER: builtins.int
    DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    ROOT_DESIRED_STATE_ID_FIELD_NUMBER: builtins.int
    DECISION_FIELD_NUMBER: builtins.int
    EXPLANATION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DESIRED_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    CURRENT_FIELD_NUMBER: builtins.int
    STATUS_EXPLANATIONS_FIELD_NUMBER: builtins.int
    @property
    def id(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier: ...
    desired_state_id: builtins.str
    root_desired_state_id: builtins.str
    decision: global___KeyDeliveryDecisionEvent.Decision.ValueType
    explanation: builtins.str
    """optional, may not always be set. when not set, the context should be obvious from status_explanations"""
    status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType
    @property
    def desired(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def target(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def current(self) -> prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State: ...
    @property
    def status_explanations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation]: ...
    def __init__(
        self,
        *,
        id: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Identifier | None = ...,
        desired_state_id: builtins.str = ...,
        root_desired_state_id: builtins.str = ...,
        decision: global___KeyDeliveryDecisionEvent.Decision.ValueType = ...,
        explanation: builtins.str = ...,
        status: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.Status.ValueType = ...,
        desired: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        target: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        current: prodvana.proto.prodvana.desired_state.model.desired_state_pb2.State | None = ...,
        status_explanations: collections.abc.Iterable[prodvana.proto.prodvana.desired_state.model.desired_state_pb2.StatusExplanation] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["current", b"current", "desired", b"desired", "id", b"id", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["current", b"current", "decision", b"decision", "desired", b"desired", "desired_state_id", b"desired_state_id", "explanation", b"explanation", "id", b"id", "root_desired_state_id", b"root_desired_state_id", "status", b"status", "status_explanations", b"status_explanations", "target", b"target"]) -> None: ...

global___KeyDeliveryDecisionEvent = KeyDeliveryDecisionEvent

class EventDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SET_DESIRED_STATE_FIELD_NUMBER: builtins.int
    SET_TARGET_STATE_FIELD_NUMBER: builtins.int
    PROGRAM_EXIT_FIELD_NUMBER: builtins.int
    APPLY_TARGET_STATE_FIELD_NUMBER: builtins.int
    MANUAL_APPROVAL_FIELD_NUMBER: builtins.int
    CUSTOM_TASK_EXECUTION_FIELD_NUMBER: builtins.int
    RUNTIME_UPDATE_FIELD_NUMBER: builtins.int
    DELIVERY_PROGRESS_FIELD_NUMBER: builtins.int
    DELIVERY_PROMOTION_FIELD_NUMBER: builtins.int
    DESIRED_STATE_STATUS_CHANGE_FIELD_NUMBER: builtins.int
    KEY_DELIVERY_DECISION_FIELD_NUMBER: builtins.int
    @property
    def set_desired_state(self) -> global___SetDesiredStateEvent: ...
    @property
    def set_target_state(self) -> global___SetTargetStateEvent: ...
    @property
    def program_exit(self) -> global___ProgramExitEvent: ...
    @property
    def apply_target_state(self) -> global___ApplyTargetStateEvent: ...
    @property
    def manual_approval(self) -> global___ManualApprovalEvent: ...
    @property
    def custom_task_execution(self) -> global___CustomTaskExecutionEvent: ...
    @property
    def runtime_update(self) -> global___RuntimeUpdateEvent: ...
    @property
    def delivery_progress(self) -> global___DeliveryProgressEvent: ...
    @property
    def delivery_promotion(self) -> global___DeliveryManualPromotionEvent: ...
    @property
    def desired_state_status_change(self) -> global___DesiredStateStatusChangeEvent: ...
    @property
    def key_delivery_decision(self) -> global___KeyDeliveryDecisionEvent: ...
    def __init__(
        self,
        *,
        set_desired_state: global___SetDesiredStateEvent | None = ...,
        set_target_state: global___SetTargetStateEvent | None = ...,
        program_exit: global___ProgramExitEvent | None = ...,
        apply_target_state: global___ApplyTargetStateEvent | None = ...,
        manual_approval: global___ManualApprovalEvent | None = ...,
        custom_task_execution: global___CustomTaskExecutionEvent | None = ...,
        runtime_update: global___RuntimeUpdateEvent | None = ...,
        delivery_progress: global___DeliveryProgressEvent | None = ...,
        delivery_promotion: global___DeliveryManualPromotionEvent | None = ...,
        desired_state_status_change: global___DesiredStateStatusChangeEvent | None = ...,
        key_delivery_decision: global___KeyDeliveryDecisionEvent | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["apply_target_state", b"apply_target_state", "custom_task_execution", b"custom_task_execution", "delivery_progress", b"delivery_progress", "delivery_promotion", b"delivery_promotion", "desired_state_status_change", b"desired_state_status_change", "details", b"details", "key_delivery_decision", b"key_delivery_decision", "manual_approval", b"manual_approval", "program_exit", b"program_exit", "runtime_update", b"runtime_update", "set_desired_state", b"set_desired_state", "set_target_state", b"set_target_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["apply_target_state", b"apply_target_state", "custom_task_execution", b"custom_task_execution", "delivery_progress", b"delivery_progress", "delivery_promotion", b"delivery_promotion", "desired_state_status_change", b"desired_state_status_change", "details", b"details", "key_delivery_decision", b"key_delivery_decision", "manual_approval", b"manual_approval", "program_exit", b"program_exit", "runtime_update", b"runtime_update", "set_desired_state", b"set_desired_state", "set_target_state", b"set_target_state"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["details", b"details"]) -> typing_extensions.Literal["set_desired_state", "set_target_state", "program_exit", "apply_target_state", "manual_approval", "custom_task_execution", "runtime_update", "delivery_progress", "delivery_promotion", "desired_state_status_change", "key_delivery_decision"] | None: ...

global___EventDetails = EventDetails



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: prodvana/common_config/env.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from prodvana.proto.validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n prodvana/common_config/env.proto\x12\x16prodvana.common_config\x1a\x17validate/validate.proto\"w\n\x08\x45nvValue\x12\x0f\n\x05value\x18\x01 \x01(\tH\x00\x12\x14\n\nraw_secret\x18\x02 \x01(\tH\x00\x12\x30\n\x06secret\x18\x03 \x01(\x0b\x32\x1e.prodvana.common_config.SecretH\x00\x42\x12\n\x0bvalue_oneof\x12\x03\xf8\x42\x01\"8\n\x06Secret\x12\x14\n\x03key\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x18\n\x07version\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x42RZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_configb\x06proto3')



_ENVVALUE = DESCRIPTOR.message_types_by_name['EnvValue']
_SECRET = DESCRIPTOR.message_types_by_name['Secret']
EnvValue = _reflection.GeneratedProtocolMessageType('EnvValue', (_message.Message,), {
  'DESCRIPTOR' : _ENVVALUE,
  '__module__' : 'prodvana.common_config.env_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.EnvValue)
  })
_sym_db.RegisterMessage(EnvValue)

Secret = _reflection.GeneratedProtocolMessageType('Secret', (_message.Message,), {
  'DESCRIPTOR' : _SECRET,
  '__module__' : 'prodvana.common_config.env_pb2'
  # @@protoc_insertion_point(class_scope:prodvana.common_config.Secret)
  })
_sym_db.RegisterMessage(Secret)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZPgithub.com/prodvana/prodvana-public/go/prodvana-sdk/proto/prodvana/common_config'
  _ENVVALUE.oneofs_by_name['value_oneof']._options = None
  _ENVVALUE.oneofs_by_name['value_oneof']._serialized_options = b'\370B\001'
  _SECRET.fields_by_name['key']._options = None
  _SECRET.fields_by_name['key']._serialized_options = b'\372B\004r\002\020\001'
  _SECRET.fields_by_name['version']._options = None
  _SECRET.fields_by_name['version']._serialized_options = b'\372B\004r\002\020\001'
  _ENVVALUE._serialized_start=85
  _ENVVALUE._serialized_end=204
  _SECRET._serialized_start=206
  _SECRET._serialized_end=262
# @@protoc_insertion_point(module_scope)
